@@ -4,7 +4,6 @@
 
 #include "gd.h"
 #include "gdtest.h"
-#include "test_config.h"
 
 #define WIDTH 60
 #define HEIGHT 50
@@ -50,8 +49,8 @@ gdImagePtr mkcross() {
 void
 do_test() {
 
-    gdTestAssertMsg(strchr("123",'2') != 0, "strchr() is not functional.\n",1);
-    gdTestAssertMsg(strcasecmp("123abC","123Abc") == 0, "strcasecmp() is not functional.\n",1);
+    gdTestAssertMsg(strchr("123",'2') != 0, "strchr() is not functional.\n");
+    gdTestAssertMsg(strcasecmp("123abC","123Abc") == 0, "strcasecmp() is not functional.\n");
     
     int n;
     struct {
@@ -70,13 +69,10 @@ do_test() {
         {"img.wbmp",    0,  1,  0},
         {"img.bmp",     0,  1,  0},
         {"img-ref.xpm", 0,  0,  1},
-        
-        // These break the test so I'm skipping them since the point
-        // of this test is not those loaders.
-        {"img-ref.xbm", 0, -1,  1},
-        {"img-ref.tga", 0, -1,  1},
-        {"img.webp",    0, -1,  0},
-        {"img.tiff",    0, -1,  0},
+        {"img-ref.xbm", 0,  1,  1},
+        {"img-ref.tga", 0,  1,  1},
+        {"img.webp",   10,  1,  0},
+        {"img.tiff",    0,  1,  0},
 
         {NULL, 0}
     };
@@ -84,7 +80,8 @@ do_test() {
     for (n = 0; names[n].nm; n++) {
         gdImagePtr orig, copy;
         int status;
-        char *full_filename;
+        char *full_filename = NULL;
+        unsigned int pixels;
 
         /* Some image readers are buggy and crash the program so we
          * skip them.  Bug fixers should remove these from the list of
@@ -98,7 +95,7 @@ do_test() {
          * it.  (If it's one of the built-in types, *that* a different
          * problem; we assert that here.) */
         if (!gdSupportsFileType(names[n].nm, 0)) {
-            gdTestAssertMsg(!names[n].required, "GD doesn't support required file type: %s\n", full_filename);
+            gdTestAssertMsg(!names[n].required, "GD doesn't support required file type: %s\n", names[n].nm);
             continue;
         }/* if */
 
@@ -121,10 +118,8 @@ do_test() {
         gdTestAssertMsg(!!copy, "Failed to load %s\n", full_filename);
         if (!copy) continue;
 
-        /* Debug printf. */
-        //printf("%s -> %d\n", full_filename, gdMaxPixelDiff(orig, copy));
-        
-        gdTestAssertMsg(gdMaxPixelDiff(orig, copy) <= names[n].maxdiff,"Pixels different on %s\n", full_filename, full_filename);
+        pixels = gdMaxPixelDiff(orig, copy);
+        gdTestAssertMsg(pixels <= names[n].maxdiff, "%u pixels different on %s\n", pixels, full_filename);
 
         if (!names[n].readonly) {
             status = remove(full_filename);
@@ -154,7 +149,7 @@ do_errortest() {
 }/* do_errortest*/
 
 
-int main(int argc, char **argv)
+int main()
 {
 
     do_test();
